==> bouml_2.2.2.tar.gz: bouml_2.2.2/src/dialog/ColMsgTable.h <==
// *************************************************************************
//
// Copyright (C) 2004,2005 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef COLMSGTABLE_H
#define COLMSGTABLE_H

#include "MyTable.h"

class ColMsg;

class ColDiagramView;

class ColMsgTable : public MyTable {
  Q_OBJECT
    
  protected:
    bool rec;
    ColDiagramView * view;
    QList<ColMsg> & msgs;
    QValueList<ColMsg *> flat_msg_list;
    
    void refresh();
    void refresh(QList<ColMsg> & m);
    void edit_msg(int row);
    void change_ranks(int row, int col);
    
  public:
    ColMsgTable(QWidget * parent, ColDiagramView * v, QList<ColMsg> & m);
 
  protected slots:
    virtual void button_pressed(int row, int col, int button, const QPoint & mousePos);
};

#endif

==> bouml_2.7.4.tar.gz: bouml_2.7.4/src/dialog/ColMsgTable.h <==
// *************************************************************************
//
// Copyright (C) 2004,2005 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef COLMSGTABLE_H
#define COLMSGTABLE_H

#include "MyTable.h"

class ColMsg;
class ColMsgList;

class ColDiagramView;

class ColMsgTable : public MyTable {
  Q_OBJECT
    
  protected:
    bool rec;
    ColDiagramView * view;
    ColMsgList & msgs;
    QValueList<ColMsg *> flat_msg_list;
    
    void refresh();
    void refresh(ColMsgList & m);
    void edit_msg(int row);
    void change_ranks(int row, int col);
    
  public:
    ColMsgTable(QWidget * parent, ColDiagramView * v, ColMsgList & m);
 
  protected slots:
    virtual void button_pressed(int row, int col, int button, const QPoint & mousePos);
};

#endif
